@@ -125,7 +125,7 @@ class Code():
 			#self.__class__.__name__ = "Version"
 
 			# check self instance.
-			if isinstance(value, Formats.Version):
+			if isinstance(value, Version):
 				self.value = value.value
 
 			# init.
@@ -190,7 +190,7 @@ class Code():
 			else:
 				raise Exceptions.FormatError(f"Can not add object {self.__class__} & {count.__class__}, a version should be incremented with a count (example: 1).")
 			value = self.increase(value=self.value, count=count)
-			return Formats.Version(value)
+			return Version(value)
 		def __concat__(self, count):
 			if isinstance(vercount, (int, float)):
 				a=1
@@ -199,7 +199,7 @@ class Code():
 			else:
 				raise Exceptions.FormatError(f"Can not concat object {self.__class__} & {count.__class__}, a version should be incremented with a count (example: 1).")
 			value = self.increase(value=self.value, count=count)
-			return Formats.Version(value)
+			return Version(value)
 		def __pos__(self, count):
 			if isinstance(count, (int, float)):
 				a=1
@@ -208,7 +208,7 @@ class Code():
 			else:
 				raise Exceptions.FormatError(f"Can not pos object {self.__class__} & {count.__class__}, a version should be incremented with a count (example: 1).")
 			value = self.increase(value=self.value, count=count)
-			return Formats.Version(value)
+			return Version(value)
 		def __iadd__(self, count):
 			if isinstance(count, (int, float)):
 				a=1
@@ -369,7 +369,7 @@ class Code():
 		def assign(self, string):
 			if isinstance(data, (int, float)):
 				a=1
-			elif isinstance(data, (Formats.String)):
+			elif isinstance(data, (String)):
 				data = data.string
 			elif isinstance(data, self.__class__):
 				data = data.data
@@ -450,8 +450,7 @@ class Code():
 			if data == None: data = self.data
 			if data == None: raise Exceptions.InvalidUsage("Define parameter: [data].")
 			data = data.replace("	","    ")
-			if not keep_indent: before="\n"
-			else: before = " "
+			before = "\n"
 			if len(data) > 0 and data[0] != before: data = before+str(data)
 			while True:
 				if "	" in data: data = data.replace("	","    ")
@@ -474,8 +473,13 @@ class Code():
 				elif " \n" in data: data = data.replace(" \n", "\n")
 				else: break
 			classes = []
-			#slices = data.split(f"{before}class ")
-			slices = String(data).split([" class ", "\nclass "])
+			to_slice = []
+			for i in range(100):
+				l = "\n"
+				for _ in range(i): l += " "
+				l += "class "
+				to_slice.append(l)
+			slices = String(data).split(to_slice)
 			if len(slices) == 1:
 				if format == dict:
 					return {}
@@ -526,7 +530,7 @@ class Code():
 									while True:
 										if ("\nclass " in class_code or " class " in class_code or (len(class_code) >= len("class ") and class_code[:len("class ")] == "class ")) and class_code != data and len(class_code) > 0:
 											# get the depth of the class inside the class.
-											inside_class_code_indent = class_code.line_indent(line=class_code.split("\n")[1])
+											inside_class_code_indent = String(class_code).line_indent(line=class_code.split("\n")[1])
 											inside_class_code_depth = 0
 											for line in class_code.split("\n"):
 												if str(String(line).line_indent(line=line)) == str(0):
@@ -730,7 +734,8 @@ class Code():
 			
 			# normalize.
 			data = data.replace("	","    ")
-			if len(data) > 0 and data[0] != "\n": data = "\n"+str(data)
+			before = "\n"
+			if len(data) > 0 and data[0] != before: data = before+str(data)
 			while True:
 				if "	" in data: data = data.replace("	","    ")
 				elif ") :" in data: data = data.replace(") :","):")
@@ -755,7 +760,13 @@ class Code():
 			
 			# slice with all indent (less dependable).
 			if indent == None:
-				slices = String(data).split([" def ", "\ndef "])
+				to_slice = []
+				for i in range(100):
+					l = "\n"
+					for _ in range(i): l += " "
+					l += "def "
+					to_slice.append(l)
+				slices = String(data).split(to_slice)
 
 			# slice by ident line.
 			else:
@@ -881,7 +892,7 @@ class Code():
 			# banned sub paths.
 			banned=[],
 			# banned names.
-			banned_names=["__main__.py", "utils.py", ".version.py"],
+			banned_names=["__main__.py", "utils.py", ".version"],
 			# banned basenames.
 			banned_basenames=["utils", "__pycache__", ".legacy"],
 			# banned class types.
@@ -958,7 +969,7 @@ class Code():
 					if notes != None:
 						for i in notes: doc += f"{i}\n"
 					doc += (
-						f"from {package} import " + module + "\n" +
+						f"from {package} import " + module.split('.')[0] + "\n" +
 						"")
 				else:
 					doc = (
@@ -1152,7 +1163,7 @@ class Code():
 			# banned sub paths.
 			banned=[],
 			# banned names.
-			banned_names=["__main__.py", "utils.py", ".version.py"],
+			banned_names=["__main__.py", "utils.py", ".version"],
 			# banned basenames.
 			banned_basenames=["utils", "__pycache__", ".legacy"],
 			# banned class types.
@@ -1321,7 +1332,7 @@ class Code():
 		def assign(self, string):
 			if isinstance(data, (int, float)):
 				a=1
-			elif isinstance(data, (Formats.String)):
+			elif isinstance(data, (String)):
 				data = data.string
 			elif isinstance(data, self.__class__):
 				data = data.data
@@ -1336,3 +1347,8 @@ class Code():
 	
 
 	#
+
+# shortcuts.
+Version = Code.Version
+Script = Code.Script
+Python = Code.Python
\ No newline at end of file
