@@ -230,7 +230,7 @@ class __Response__(Docs):
 		elif response.__class__.__name__ in ["ResponseObject"]:
 			return response
 		
-		# check syst3m.console.Output.
+		# check Console.Output.
 		elif response.__class__.__name__ in ["Output"]:
 			try:
 				return response.response()
@@ -315,9 +315,15 @@ class __Response__(Docs):
 	#
 	
 # the parameters manager object class.
-class Parameters(object):
+class Parameters(Docs):
 	def __init__(self):
-		a=1
+		
+		# docs.
+		Docs.__init__(self,
+			initialized=True,
+			module="Response.parameters", 
+			notes=[], )
+
 		#
 	# get request parameters.
 	def get(self, 
@@ -466,6 +472,9 @@ class Parameters(object):
 # the response & parameters object class.
 class ResponseObject(object):
 	def __init__(self, 
+		#
+		# Should be initialized with Response.success or Response.error.
+		#
 		# the response attributes.
 		attributes={
 			"success":False,
@@ -804,7 +813,7 @@ class ResponseObject(object):
 	# return raw data.
 	def raw(self):
 		return self.dict()
-	# return response self for syst3m.console.Output and other objects that init ResponseObject as self and want it to be converted to response.
+	# return response self for Console.Output and other objects that init ResponseObject as self and want it to be converted to response.
 	def response(self):
 		return self
 		#
